mangadap.proc.stellarcontinuummodel module
==========================================

.. automodule:: mangadap.proc.stellarcontinuummodel
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
